@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
 from django.contrib.sites.models import get_current_site
-from django.core.mail import BadHeaderError, EmailMessage
 from django.core.exceptions import ImproperlyConfigured
+from django.core.mail import BadHeaderError, EmailMessage
+from django.core.urlresolvers import reverse
 from django.http import HttpResponse
 from django.template.loader import render_to_string
+from django.utils.translation import ugettext_lazy as _
 from django.views.generic import FormView, TemplateView
 
-
 from contato.forms import AntiSpamContactForm, ContactForm
 
 
@@ -49,7 +49,7 @@ class BaseContactView(FormView):
                 raise ImproperlyConfigured('Please provide a recipient_list')
         return recipient_list
 
-    def get_sender_email(self, form_data):
+    def get_from_email(self, form_data):
         raise NotImplementedError
 
     def get_subject(self, form_data):
@@ -58,17 +58,22 @@ class BaseContactView(FormView):
     def get_body(self, form_data):
         raise NotImplementedError
 
-    def send(self, form_data, fail_silently=False):
-        subject, body = self.get_subject(form_data), self.get_body(form_data)
-        sender_email = self.get_sender_email(form_data)
+    def get_headers(self, form_data):
+        raise NotImplementedError
+
+    def create_email(self, form_data):
         recipient_list = self.get_recipient_list()
-        email = EmailMessage(
-            subject, body, settings.DEFAULT_FROM_EMAIL, recipient_list,
-            headers={'Reply-To': sender_email}
-        )
-        email.send(fail_silently=fail_silently)
+        from_email = self.get_from_email(form_data)
+        subject = self.get_subject(form_data)
+        body = self.get_body(form_data)
+        headers = self.get_headers(form_data)
+        email = EmailMessage(subject, body, from_email, recipient_list, headers=headers)
         return email
 
+    def send(self, form_data, fail_silently=False):
+        email = self.create_email(form_data)
+        email.send(fail_silently=fail_silently)
+
     def form_valid(self, form):
         try:
             self.send(form.cleaned_data)
@@ -91,23 +96,39 @@ class ContactView(BaseContactView):
             site_name = get_current_site(self.request).name
         return site_name
 
-    def get_sender_email(self, form_data):
-        name, email = form_data.get('name'), form_data.get('email')
-        return '%s <%s>' % (name, email)
+    def get_from_email(self, form_data):
+        sender_name = form_data.get('name')
+        from_email = settings.DEFAULT_FROM_EMAIL
+        return '%s <%s>' % (sender_name, from_email)
 
     def get_subject(self, form_data):
+        subject = _('Message from the website contact form')
         site_name = self.get_site_name()
         template = self.get_subject_template()
-        string = render_to_string(template, {'site_name': site_name})
+        string = render_to_string(template, {
+            'subject': subject,
+            'site_name': site_name,
+            'form_data': form_data
+        })
         return string.strip()
 
     def get_body(self, form_data):
         message = form_data.get('message')
+        site_name = self.get_site_name()
         template = self.get_body_template()
-        context = dict(message=message)
-        string = render_to_string(template, context)
+        string = render_to_string(template, {
+            'message': message,
+            'site_name': site_name,
+            'form_data': form_data,
+        })
         return string.lstrip()
 
+    def get_headers(self, form_data):
+        sender_name = form_data.get('name')
+        sender_email = form_data.get('email')
+        reply_to = '%s <%s>' % (sender_name, sender_email)
+        return {'Reply-To': reply_to}
+
 
 class AntiSpamContactView(ContactView):
     form_class = AntiSpamContactForm
